#include <qlineedit.h>

#ifdef QT4
#include <QGroupBox>
#else
#include <qvgroupbox.h>
#include <qhgroupbox.h>
#include <qvbox.h>
#include <qhbuttongroup.h>
#endif

#include <qlayout.h>
#include <qradiobutton.h>
#include <qpushbutton.h>
#include <qtextcodec.h>
#include <qfileinfo.h>
#include "simplefiledialog.h"
#include "coverartconfig.h"

void CoverArtConfig::setStatesByConfiguration(const Configuration& config)
{
    ConfigView::setStatesByConfiguration(config);

    coverArtDirectory_->setText(config.coverArtDirectory);
    coverArtFlowCacheDirectory_->setText(config.coverArtFlowCacheDirectory);
}

void CoverArtConfig::createWidgets()
{
    ConfigView::createWidgets();

    QVBoxLayout *layout = new QVBoxLayout(widget());
    layout->setSpacing(4);

#ifdef QT4
    QGroupBox *pathGroup = new QGroupBox(tr("Cover Art location"), widget());
    QHBoxLayout *pathGroupLayout = new QHBoxLayout(pathGroup);
#else
    QHGroupBox *pathGroup = new QHGroupBox(tr("Cover Art location"), widget());
#endif

    layout->addWidget(pathGroup);

    coverArtDirectory_ = new QLineEdit(pathGroup);
    QPushButton *openButton = new QPushButton(tr("..."), pathGroup);

#ifdef QT4
    pathGroupLayout->addWidget(coverArtDirectory_);
    pathGroupLayout->addWidget(openButton);
#endif

    connect(coverArtDirectory_, SIGNAL(textChanged(const QString&)), this, SLOT(setCoverArtDirectory(const QString&)));
    connect(openButton, SIGNAL(clicked()), this, SLOT(execCoverArtDirectoryDialog()));

#ifdef QT4
    QGroupBox *coverArtFlowGroup = new QGroupBox(tr("Cover Art Flow Settings"), widget());
    QHBoxLayout *coverArtFlowGroupLayout = new QHBoxLayout(coverArtFlowGroup);
#else
    QHGroupBox *coverArtFlowGroup = new QHGroupBox(tr("Cover Art Flow Settings"), widget());
#endif

    layout->addWidget(coverArtFlowGroup);

    coverArtFlowCacheDirectory_ = new QLineEdit(coverArtFlowGroup);
    openButton = new QPushButton(tr("..."), coverArtFlowGroup);

#ifdef QT4
    coverArtFlowGroupLayout->addWidget(coverArtFlowCacheDirectory_);
    coverArtFlowGroupLayout->addWidget(openButton);
#endif

    connect(coverArtFlowCacheDirectory_, SIGNAL(textChanged(const QString&)), this, SLOT(setCoverArtFlowCacheDirectory(const QString&)));
    connect(openButton, SIGNAL(clicked()), this, SLOT(execCoverArtFlowCacheDirectory()));
}

void CoverArtConfig::execCoverArtDirectoryDialog()
{
    QString newDirectory = SimpleFileDialog::getExistingDirectory(
        QFileInfo(coverArtDirectory_->text()).filePath(),
        this,
        "get cover art directory",
        tr("Please choose a new Cover Art directory"),
        true,
        true
    );

    if (!newDirectory.isNull())
        coverArtDirectory_->setText(newDirectory);
}

void CoverArtConfig::execCoverArtFlowCacheDirectory()
{
    QString newDirectory = SimpleFileDialog::getExistingDirectory(
        QFileInfo(coverArtFlowCacheDirectory_->text()).filePath(),
        this,
        "get cover art flow cache directory",
        tr("Please choose a new Cover Art Flow Cache directory"),
        true,
        true
    );

    if (!newDirectory.isNull())
        coverArtFlowCacheDirectory_->setText(newDirectory);
}
